@@ -71,7 +71,13 @@ class TrajectoryExporter:
                             domain=self.domain,
                             grounded_action_call=action_descriptor.parameters,
                             problem_objects=problem_objects)
-        next_state = operator.apply(previous_state, allow_inapplicable_actions=self.allow_invalid_actions)
+        try:
+            next_state = operator.apply(previous_state, allow_inapplicable_actions=self.allow_invalid_actions)
+
+        except ValueError:
+            self.logger.debug("In case an action is inappliable, the state remains unchanged.")
+            next_state = previous_state
+
         return TrajectoryTriplet(previous_state=previous_state,
                                  op=operator,
                                  next_state=next_state)
