@@ -18,10 +18,12 @@ class Predicate:
         if predicate:
             self.name = predicate.name
             self.signature = predicate.signature.copy()
+            self.is_positive = predicate.is_positive
 
         else:
             self.name = name
             self.signature = signature
+            self.is_positive = is_positive
 
     def __eq__(self, other: "Predicate") -> bool:
         """Checks whether two predicates are considered equal.
@@ -39,7 +41,7 @@ class Predicate:
                 return False
 
             other_param_type = other.signature[parameter_name]
-            if not parameter_type.is_sub_type(other_param_type):
+            if not parameter_type == other_param_type and not parameter_type.is_sub_type(other_param_type):
                 return False
 
         return True
